from dataclasses import dataclass


@dataclass
class DataObjectOutCol:
    name: str
    type: str
    type_change: str
